import { IRepository } from 'aws-cdk-lib/aws-ecr';
import { DockerImageAsset } from 'aws-cdk-lib/aws-ecr-assets';
import { Construct } from 'constructs';
export interface SociIndexBuildProps {
    /**
     * The ECR repository your container image is stored.
     * You can only specify a repository in the same environment (account/region).
     * The index artifact will be uploaded to this repository.
     */
    readonly repository: IRepository;
    /**
     * The tag of the container image you want to build index for.
     */
    readonly imageTag: string;
}
/**
 * Build and publish a SOCI index for a container image.
 * A SOCI index helps start Fargate tasks faster in some cases.
 * Please read the following document for more details: https://docs.aws.amazon.com/AmazonECS/latest/userguide/container-considerations.html
 */
export declare class SociIndexBuild extends Construct {
    /**
     * A utility method to create a SociIndexBuild construct from a DockerImageAsset instance.
     */
    static fromDockerImageAsset(scope: Construct, id: string, imageAsset: DockerImageAsset): SociIndexBuild;
    constructor(scope: Construct, id: string, props: SociIndexBuildProps);
}
